@@ -376,17 +376,16 @@ class Ext2:
     :param base_address: It is the offset (byte number), inside the device, where
         the partition (with an ext2 fs) that we want to analyze, begins.
     """
-    def __init__(self, path, base_address):
+    def __init__(self, handle, base_address):
         """
         The storage device is opened.
         The byte pointer is positioned at the beginning of the desired partition.
         And the boot area, the superblock (original), the group descriptor table
         (original) and the root inode, are read.
         """
-        self.path = path
         self.base_address = base_address
 
-        self.handle = open(path, "rb") # read-only for now (for security, I should set this attribute as private through properties)
+        self.handle = handle # read-only for now (for security, I should set this attribute as private through properties)
         self.handle.seek(self.base_address)
 
         # the first 2 sectors of the partition correspond to the boot area (are unused by the ext2 filesystem).
